@@ -24,11 +24,13 @@ class Filters(object):
       self.add( Filter('default') )
 
       if path is None:
+         if module_name is None:
+            module_name = __name__.split('.')[0]
          if module_name is not None and module_name in sys.modules:
             mod = sys.modules[module_name]
-            path = os.path.dirname( getabsfile(mod) ) + '/custom_filters'
+            path = os.path.join(os.path.dirname( getabsfile(mod) ), 'custom_filters')
          else:
-            path='./custom_filters'
+            path=os.path.join('.', 'custom_filters' )
       self.load(path)
 
    #********************************
